==> CGAL-6.0-doc_html.tar.xz: doc_html/Algebraic_kernel_d/index.js <==
var index =
[
    [ "Introduction", "index.html#Algebraic_kernel_dIntroduction", null ],
    [ "Algebraic Kernel Concepts", "index.html#Algebraic_kernel_dAlgebraic", [
      [ "Univariate Algebraic Kernel", "index.html#Algebraic_kernel_dUnivariateAlgebraicKernel", null ],
      [ "Major Types", "index.html#Algebraic_kernel_dMajorTypes", null ],
      [ "Construction of Algebraic Real Numbers", "index.html#Algebraic_kernel_dConstructionofAlgebraic", null ],
      [ "Comparison and Approximation of Algebraic Real Numbers", "index.html#Algebraic_kernel_dComparisonandApproximation", null ],
      [ "Interplay with Polynomials", "index.html#Algebraic_kernel_dInterplaywithPolynomials", null ],
      [ "Auxiliary Functionality for Polynomials", "index.html#Algebraic_kernel_dAuxiliaryFunctionality", null ],
      [ "Design Rationale", "index.html#Algebraic_kernel_dDesignRationale", null ],
      [ "Bivariate Algebraic Kernel", "index.html#Algebraic_kernel_dBivariateAlgebraicKernel", null ]
    ] ],
    [ "Models", "index.html#Algebraic_kernel_dModels", [
      [ "Generic Algebraic Kernels", "index.html#Algebraic_kernel_dGenericAlgebraicKernels", null ],
      [ "Algebraic Kernels Based on RS", "index.html#Algebraic_kernel_dAlgebraicKernelsBasedon", null ]
    ] ],
    [ "Examples", "index.html#Algebraic_kernel_dExamples", [
      [ "Construction of Algebraic Real Numbers", "index.html#CGALAK1ConstructionExamples", null ],
      [ "Solving Univariate Polynomials", "index.html#CGALAK1Solving", null ],
      [ "Comparison and Approximation of Algebraic Real Numbers", "index.html#CGALAK1EGCompare_1", null ],
      [ "Isolation of Algebraic Real Numbers with respect to roots of other polynomials", "index.html#CGALAK1EGIsolate_1", null ],
      [ "Interplay with Polynomials", "index.html#CGALAK1EGSign_at_1", null ]
    ] ],
    [ "Design and Implementation History", "index.html#Algebraic_kernel_dDesign", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Algebraic_kernel_d/index.js <==
var index =
[
    [ "Introduction", "index.html#Algebraic_kernel_dIntroduction", null ],
    [ "Algebraic Kernel Concepts", "index.html#Algebraic_kernel_dAlgebraic", [
      [ "Univariate Algebraic Kernel", "index.html#Algebraic_kernel_dUnivariateAlgebraicKernel", null ],
      [ "Major Types", "index.html#Algebraic_kernel_dMajorTypes", null ],
      [ "Construction of Algebraic Real Numbers", "index.html#Algebraic_kernel_dConstructionofAlgebraic", null ],
      [ "Comparison and Approximation of Algebraic Real Numbers", "index.html#Algebraic_kernel_dComparisonandApproximation", null ],
      [ "Interplay with Polynomials", "index.html#Algebraic_kernel_dInterplaywithPolynomials", null ],
      [ "Auxiliary Functionality for Polynomials", "index.html#Algebraic_kernel_dAuxiliaryFunctionality", null ],
      [ "Design Rationale", "index.html#Algebraic_kernel_dDesignRationale", null ],
      [ "Bivariate Algebraic Kernel", "index.html#Algebraic_kernel_dBivariateAlgebraicKernel", null ]
    ] ],
    [ "Models", "index.html#Algebraic_kernel_dModels", [
      [ "Generic Algebraic Kernels", "index.html#Algebraic_kernel_dGenericAlgebraicKernels", null ]
    ] ],
    [ "Examples", "index.html#Algebraic_kernel_dExamples", [
      [ "Construction of Algebraic Real Numbers", "index.html#CGALAK1ConstructionExamples", null ],
      [ "Solving Univariate Polynomials", "index.html#CGALAK1Solving", null ],
      [ "Comparison and Approximation of Algebraic Real Numbers", "index.html#CGALAK1EGCompare_1", null ],
      [ "Isolation of Algebraic Real Numbers with respect to roots of other polynomials", "index.html#CGALAK1EGIsolate_1", null ],
      [ "Interplay with Polynomials", "index.html#CGALAK1EGSign_at_1", null ]
    ] ],
    [ "Design and Implementation History", "index.html#Algebraic_kernel_dDesign", null ]
];
